@@ -1,17 +1,13 @@
 package RT::Extension::QuickCalls;
-
-our $VERSION = '1.00';
-
 use warnings;
 use strict;
-use Carp;
 
+our $VERSION = '1.01';
 
 =head1 NAME
 
 RT::Extension::QuickCalls - Quickly create tickets in specific queues with default values
 
-
 =head1 SYNOPSIS
 
 You will need to enable the new QuickCalls portlet with a line
@@ -68,15 +64,12 @@ If you are using RT 4.2 or greater, add this line:
 
     Plugin('RT::Extension::QuickCalls');
 
-For earlier releases of RT 4, add this line:
+For RT 4.0, add this line:
 
     Set(@Plugins, qw(RT::Extension::QuickCalls));
 
 or add C<RT::Extension::QuickCalls> to your existing C<@Plugins> line.
 
-You will also need to add QuickCalls to the C<$HomepageComponents>
-configuration, as documented above.
-
 =item Clear your mason cache
 
     rm -rf /opt/rt4/var/mason_data/obj
@@ -85,50 +78,27 @@ configuration, as documented above.
 
 =back
 
-=head1 BUGS AND LIMITATIONS
-
-No bugs have been reported.
-
-Please report any bugs or feature requests to
-C<bug-rt-extension-quickcalls@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
-
-
 =head1 AUTHOR
 
-Kevin Falcone
+Best Practical Solutions, LLC E<lt>modules@bestpractical.comE<gt>
 
+=head1 BUGS
 
-=head1 LICENCE AND COPYRIGHT
+All bugs should be reported via email to
 
-Copyright (c) 2007-2014, Best Practical Solutions, LLC.  All rights reserved.
+    L<bug-RT-Extension-QuickCalls@rt.cpan.org|mailto:bug-RT-Extension-QuickCalls@rt.cpan.org>
 
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself. See L<perlartistic>.
+or via the web at
 
+    L<rt.cpan.org|http://rt.cpan.org/Public/Dist/Display.html?Name=RT-Extension-QuickCalls>.
 
-=head1 DISCLAIMER OF WARRANTY
+=head1 LICENSE AND COPYRIGHT
 
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
+This software is Copyright (c) 2014 by Best Practical Solutions
 
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
+This is free software, licensed under:
+
+  The GNU General Public License, Version 2, June 1991
 
 =cut
 
